@@ -393,6 +393,7 @@ class mediafile(object):
         self.anidburl          = pathinfo.anidb_url
         self.from_url          = pathinfo.from_url
         self.transfer          = pathinfo.transfer
+        self.complete          = pathinfo.complete
         self.filename          = os.path.basename(self.address)
         self.episodename       = findnum(self.filename)[0]
         self.episode           = int(self.episodename)
@@ -810,13 +811,14 @@ class mediafile(object):
         else:
             logger.warning('无法根据mediainfo分析出字幕语言信息')
 
-    def updatemediainfo(self,filepath='',newpath=''):
+    def updatemediainfo(self,filepath=''):
         if os.path.isdir(self.topath):
             self.address=os.path.join(self.topath,os.path.basename(self.address))
         if not (filepath=='' or filepath==None):
             a=os.popen('mediainfo --Inform=file://"'+filepath+'" "'+self.address+'"')
             res=a.buffer.read().decode('utf-8')
             a.close()
+            self.mediainfo=res
         else:
             a=os.popen('mediainfo "'+self.address+'"')
             res=a.buffer.read().decode('utf-8')
@@ -825,8 +827,14 @@ class mediafile(object):
             for i in range(len(ss)):
                 if ss[i].startswith('Complete name'):
                     ss[i]=':'.join([ss[i].split(':')[0],' '+self.filename])
+            i=0
+            while (i<len(ss)):
+                if (ss[i].upper()).startswith('Unique'.upper()):
+                    del(ss[i])
+                    i=i-1
+                i+=1
             res='\n'.join(ss)
-        self.mediainfo=res
+            self.mediainfo=res
 
     def getmediainfo(self):
         if self.getmediainfo_done==1:
@@ -842,6 +850,12 @@ class mediafile(object):
         for i in range(len(ss)):
             if ss[i].startswith('Complete name'):
                 ss[i]=':'.join([ss[i].split(':')[0],' '+self.filename])
+        i=0
+        while (i<len(ss)):
+            if (ss[i].upper()).startswith('Unique'.upper()):
+                del(ss[i])
+                i=i-1
+            i+=1
 
         self.mediainfo='\n'.join(ss)
         a=os.popen("mediainfo --Output=JSON \""+self.address+'"')
@@ -1012,7 +1026,7 @@ class mediafile(object):
             self.imdburl='https://www.imdb.com/title/'+self.imdburl+'/'
             self.pathinfo.imdb_url=self.imdburl
             logger.info('根据豆瓣信息分析，imdb链接为'+self.imdburl)
-        if (douban_dict['episodes']) :
+        if (douban_dict['episodes']) and  (not('movie' in self.mediatype.lower())):
             self.media_type='TV_series'
             try:
                 self.num=int(douban_dict['episodes'])
@@ -1211,6 +1225,9 @@ class mediafile(object):
         self.mktorrent_done=1
 
     def gettorrent(self,tracker='https://announce.leaguehd.com/announce.php'):
+        if not('new_folder' in self.basic and self.basic['new_folder']>=1):
+            self.mktorrent(tracker)
+            return
         dirpath=os.path.dirname(self.topath)
         filelist=[]
         if not os.path.exists(self.topath):
@@ -1246,10 +1263,11 @@ class mediafile(object):
                         stem, suffix = os.path.splitext(c_path)
                         try:
                             os.rename(c_path,stem+'_temp'+suffix)
+                            newpath=move(stem+'_temp'+suffix,dirpath)
+                            filelist.append(newpath)
                         except Exception as r:
                             logger.error('rename temp文件"'+c_path+'"发生错误: %s' %(r))
-                        newpath=move(stem+'_temp'+suffix,dirpath)
-                        filelist.append(newpath)
+                        
 
         logger.info('检测到路径制种，将先删除掉路径里面所有种子文件(torrent后缀)以及隐藏文件（.开头的文件）...')
         deletetorrent(self.topath) 
@@ -1425,11 +1443,13 @@ class mediafile(object):
         if self.pathinfo.contenttail!='':
             self.content= self.content+self.pathinfo.contenttail
 
-        
+        '''
         if 'new_folder' in self.basic and self.basic['new_folder']>=1:
             self.gettorrent(tracker)
         else:
             self.mktorrent(tracker)
+        '''
+        self.gettorrent(tracker)
         if not (self.complete==1 or self.complete==0):
             self.complete=0
         self.getinfo_done=1
