@@ -105,7 +105,7 @@ def seedmachine_single(pathinfo,sites,pathyaml,basic,qbinfo,imgdata,hashlist):
         move_suc=0
         move_newpath=''
         move_oldpath=''
-        
+        filelist=[]
         if filepath=='' and pathinfo.zeroday_name!='':
             zeroday_path=os.path.join(pathinfo.path,pathinfo.zeroday_name)
             ls = os.listdir(zeroday_path)
@@ -157,7 +157,8 @@ def seedmachine_single(pathinfo,sites,pathyaml,basic,qbinfo,imgdata,hashlist):
                 if not upload_success:
                     logger.warning(siteitem.sitename+'第'+str(uploadtime)+'次发布任务失败')
                     logger.warning(logstr)
-                    file1.mktorrent()
+                    #file1.mktorrent()
+                    file1.gettorrent()
 
             if not upload_success:
                 logger.warning(siteitem.sitename+'发布任务失败，本站暂停发种')
@@ -292,6 +293,7 @@ def seedmachine_rest(pathinfo,sites,pathyaml,basic,qbinfo,imgdata,hashlist):
                 logger.warning(siteitem.sitename+'第'+str(uploadtime)+'次发布任务失败')
                 logger.warning(logstr)
                 #file1.mktorrent()
+                file1.gettorrent()
         if not upload_success:
             logger.warning(siteitem.sitename+'发布任务失败，本站暂停发种')
             siteitem.enable=0
@@ -385,6 +387,7 @@ def seedmachine(pathinfo,sites,pathyaml,basic,qbinfo,imgdata,hashlist):
                 logger.warning(siteitem.sitename+'第'+str(uploadtime)+'次发布任务失败')
                 logger.warning(logstr)
                 #file1.mktorrent()
+                file1.gettorrent()
 
         if not upload_success:
             logger.warning(siteitem.sitename+'发布任务失败，本站暂停发种')
@@ -397,24 +400,26 @@ def seedmachine(pathinfo,sites,pathyaml,basic,qbinfo,imgdata,hashlist):
             log_error=log_error+str(errornum)+':\t'+siteitem.sitename+'   \t'+logstr+'\n'
             logger.warning(logstr)
             #记录已发布的种子
-            for epitem in pathinfo.eps:
-                exec('pathinfo.'+siteitem.sitename+'_done.append('+str(epitem)+')')
+            if not 'movie' in pathinfo.type.lower():
+                for epitem in pathinfo.eps:
+                    exec('pathinfo.'+siteitem.sitename+'_done.append('+str(epitem)+')')
+                exec('pathinfo.'+siteitem.sitename+'_done=list(set('+'pathinfo.'+siteitem.sitename+'_done'+'))')
+                exec('pathinfo.'+siteitem.sitename+'_done.sort()')
             if pathinfo.complete==1:
                 exec('pathinfo.'+siteitem.sitename+'_done.append(-1)')
-            exec('pathinfo.'+siteitem.sitename+'_done=list(set('+'pathinfo.'+siteitem.sitename+'_done'+'))')
-            exec('pathinfo.'+siteitem.sitename+'_done.sort()')
             exec('pathyaml["'+siteitem.sitename+'"]=",".join([str(i) for i in pathinfo.'+siteitem.sitename+'_done])')
         else:
             succnum=succnum+1
             log_succ=log_succ+str(succnum)+':\t'+siteitem.sitename+'   \t'+logstr+'\n'
             logger.info(logstr)
             #记录已发布的种子
-            for epitem in pathinfo.eps:
-                exec('pathinfo.'+siteitem.sitename+'_done.append('+str(epitem)+')')
+            if not 'movie' in pathinfo.type.lower():
+                for epitem in pathinfo.eps:
+                    exec('pathinfo.'+siteitem.sitename+'_done.append('+str(epitem)+')')
+                exec('pathinfo.'+siteitem.sitename+'_done=list(set('+'pathinfo.'+siteitem.sitename+'_done'+'))')
+                exec('pathinfo.'+siteitem.sitename+'_done.sort()')
             if pathinfo.complete==1:
                 exec('pathinfo.'+siteitem.sitename+'_done.append(-1)')
-            exec('pathinfo.'+siteitem.sitename+'_done=list(set('+'pathinfo.'+siteitem.sitename+'_done'+'))')
-            exec('pathinfo.'+siteitem.sitename+'_done.sort()')
             exec('pathyaml["'+siteitem.sitename+'"]=",".join([str(i) for i in pathinfo.'+siteitem.sitename+'_done])')
             #deletetorrent(basic['screenshot_path'])
         #a=input('check')
