@@ -218,11 +218,11 @@ def redleaves_upload(siteinfo,file1,record_path,qbinfo,basic,hashlist):
             "descr": file1.pathinfo.contenthead+'\n'+file1.douban_info+'\n'+file1.screenshoturl+'\n'+file1.pathinfo.contenttail,
             "technical_info": file1.mediainfo,
             "type": select_type,
-            "medium_sel": medium_sel,
-            "codec_sel": codec_sel,
-            "audiocodec_sel": audiocodec_sel,
-            "standard_sel": standard_sel,
-            "processing_sel" : processing_sel,
+            "medium_sel[5]": medium_sel,
+            "codec_sel[5]": codec_sel,
+            "audiocodec_sel[5]": audiocodec_sel,
+            "standard_sel[5]": standard_sel,
+            "processing_sel[5]" : processing_sel,
             "uplver": uplver,
             "tags[]": tags,
             }
