@@ -207,13 +207,13 @@ def sharkpt_upload(siteinfo,file1,record_path,qbinfo,basic,hashlist):
             "descr": file1.pathinfo.contenthead+'\n'+file1.douban_info+'\n'+file1.screenshoturl+'\n'+file1.pathinfo.contenttail,
             "technical_info": file1.mediainfo,
             "type": select_type,
-            "medium_sel": medium_sel,
-            "codec_sel": codec_sel,
-            "audiocodec_sel": audiocodec_sel,
-            "standard_sel": standard_sel,
-            "team_sel": team_sel,
+            "medium_sel[4]": medium_sel,
+            "codec_sel[4]": codec_sel,
+            "audiocodec_sel[4]": audiocodec_sel,
+            "standard_sel[4]": standard_sel,
+            "team_sel[4]": team_sel,
             "uplver": uplver,
-            "tags[]": tags,
+            "tags[4][]": tags,
             "pos_state": pos_state,
             "pos_state_until": pos_state_until
             }
